# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from rcabench.openapi.models.dto_dataset_v2_label_create_req import DtoDatasetV2LabelCreateReq
from typing import Optional, Set
from typing_extensions import Self

class DtoDatasetV2CreateReq(BaseModel):
    """
    DtoDatasetV2CreateReq
    """ # noqa: E501
    data_source: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="数据来源描述")
    description: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="数据集描述")
    format: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="数据格式")
    injection_ids: Optional[List[StrictInt]] = Field(default=None, description="关联的故障注入ID列表")
    is_public: Optional[StrictBool] = Field(default=None, description="是否公开，可选，默认false")
    label_ids: Optional[List[StrictInt]] = Field(default=None, description="关联的标签ID列表")
    name: Annotated[str, Field(strict=True, max_length=255)] = Field(description="数据集名称")
    new_labels: Optional[List[DtoDatasetV2LabelCreateReq]] = Field(default=None, description="新建标签列表")
    project_id: Annotated[int, Field(strict=True, ge=1)] = Field(description="项目ID")
    type: Annotated[str, Field(strict=True, max_length=50)] = Field(description="数据集类型")
    version: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="数据集版本，可选，默认v1.0")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["data_source", "description", "format", "injection_ids", "is_public", "label_ids", "name", "new_labels", "project_id", "type", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DtoDatasetV2CreateReq from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in new_labels (list)
        _items = []
        if self.new_labels:
            for _item_new_labels in self.new_labels:
                if _item_new_labels:
                    _items.append(_item_new_labels.to_dict())
            _dict['new_labels'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DtoDatasetV2CreateReq from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data_source": obj.get("data_source"),
            "description": obj.get("description"),
            "format": obj.get("format"),
            "injection_ids": obj.get("injection_ids"),
            "is_public": obj.get("is_public"),
            "label_ids": obj.get("label_ids"),
            "name": obj.get("name"),
            "new_labels": [DtoDatasetV2LabelCreateReq.from_dict(_item) for _item in obj["new_labels"]] if obj.get("new_labels") is not None else None,
            "project_id": obj.get("project_id"),
            "type": obj.get("type"),
            "version": obj.get("version")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


